@@ -453,8 +453,16 @@ class SpecValidator:
         new_hdu = fits.PrimaryHDU(temp_array, header=fits.Header())
         for (key, value) in validated_headers.items():
             new_hdu.header[key] = value
-        for key in fits_cards:
-            new_hdu.header[key] = str(fits_cards[key])
+        if "HISTORY" in fits_cards:
+            for line in fits_cards["HISTORY"].splitlines():
+                new_hdu.header.add_history(line)
+            fits_cards.pop("HISTORY")
+        if "COMMENT" in fits_cards:
+            for line in fits_cards["COMMENT"].splitlines():
+                new_hdu.header.add_comment(line)
+            fits_cards.pop("COMMENT")
+        if fits_cards:
+            raise ValueError(f"Invalid keys found in fits_cards. {fits_cards.keys()=}")
         new_hdu_list = fits.HDUList([new_hdu])
         return new_hdu_list
 
